
/*===========================================================================
Project:  Inequality, Income Dynamics, and Worker Transitions:The Case of Mexico
Author:   Daniela Puggioni, Mariana Calderón, Alfonso Cebreros Zurita, León
Fernández Bujanda, José Antonio Inguanzo González, and David Jaume 
Program name: 1.build_imss_panel_annual.do
Dependencies: Banco de Mexico
Description: Prepares panel dataset with annual income. Needs to download 
command paretofit.
===========================================================================*/


set more off
clear all
cap log close

glo carpeta 	     "S:\PartB\B.1TransitionsInOutIMSS\Replication"
glo sourcedata	     "J:"
glo constructeddata	 "$carpeta/data/constructed"
glo figures 	     "$carpeta/figures"
glo logfiles	     "$carpeta/log"
glo ster		     "$carpeta/ster"
glo tables		     "$carpeta/tables"
glo code	         "$carpeta/code"

tempfile month
timer clear 1

*Load data with information on workers' year of birth
timer on 1
import delimited "$sourcedata/catalogos/Empleados.csv", clear 
rename llave_empleado nss
keep nss anio_nacimiento
tempfile yob
save "`yob'", replace 

*Loop to create the panel dataset
local dt_0 = tm(2005m1)
local dt_1 = tm(2005m12)
local cn  = 1
forvalues dt = `dt_0' (1) `dt_1' {
	local yr = year(dofm(`dt'))
	local mn = month(dofm(`dt'))
	local ms = string(`mn', "%02.0f")
	di "Procesando `yr' `mn'"
	
	*Load IMSS microdatasets
	use "$sourcedata/stata/`yr'/imss_`ms'`yr'.dta"
	rename _all, l
	
	*We keep the observation with the highest salary for workers with more than 
	*one observation
	keep llave_empleado salariof llave_empresa llave_sexo
	bysort llave_empleado (salariof): gen count = _n
	egen count_max = max(count) if salariof < ., by(llave_empleado)
	drop if salariof == . | count != count_max
	drop count*

	*Imputation of salary for topocode using Paretofit
	quietly summarize salariof, detail
	local m0 = r(p95)
	local max = r(p99)
	paretofit salariof, x0(`m0')
	local alpha = e(ba)
	local me = (`alpha'/(`alpha'-1))*`max'
	di "Valor máximo `max'" "`Valor máximo imputado `me'"
	gen salar_imp = salariof
	replace salar_imp = `me' if salariof >= `max' 
	compress
	
	*Saving montlhy panel in long form
	gen date = `dt'
	rename (llave_empleado) (nss)
	if `mn' > 1 append using "`month'"
	order nss llave_empresa* sal*, sequential
	save "`month'", replace
	
	* Preparing annual panel dataset
	if `mn' == 12 {
		gen year = year(dofm(date))
		gen wage_month_obs = salariof * 30
		gen wage_month_imp = salar_imp * 30
		collapse (sum) wage_anual_obs = wage_month_obs 						///
			wage_anual_imp = wage_month_imp, by(nss llave_sexo year)
		drop if wage_anual_obs == 0
		if `dt' > `dt_0'+12 append using "$datos_end/income_dynam_pan_new"
		compress
		save "$constructeddata/income_dynam_pan_new", replace
	}
}

*Load annual panel data set just created
use "$constructeddata/income_dynam_pan_new", clear

*Merging with dataset with yob
merge m:1 nss using "`yob'", assert(match using) keep(match) nogenerate
gen edad = year - anio_nacimiento

*Labels
label var nss "Worker's Social Security Identifier"
label var wage_anual_obs "Observed Annual Nominal Wage"
label var wage_anual_imp "Annual Nominal Wage with Imputations"
label var anio_nacimiento "Year of Birth"
label var edad "Age"
compress
save "$constructeddata/income_dynam_pan_new", replace
timer off 1
timer list 1

/* End of do-file */	