/*===========================================================================
Project:  Inequality, Income Dynamics, and Worker Transitions:The Case of Mexico
Author:   Daniela Puggioni, Mariana Calderón, Alfonso Cebreros Zurita, León
Fernández Bujanda, José Antonio Inguanzo González, and David Jaume 
Program name: 3.build_spells.do
Dependencies: Banco de Mexico
Description: Builds workers' active spells (when observed in IMSS database) and 
inactive spells (when we do not observe them in IMSS database)
===========================================================================*/

glo carpeta 	     "S:\PartB\B.1TransitionsInOutIMSS\Replication"
glo sourcedata	     "$carpeta/data/source"
glo constructeddata	 "$carpeta/data/constructed"
glo figures 	     "$carpeta/figures"
glo logfiles	     "$carpeta/log"
glo ster		     "$carpeta/ster"
glo tables		     "$carpeta/tables"
glo code	         "$carpeta/code"



*Bring back # of months a worker was present per year
    use "$constructeddata/IMSS2005.dta", replace
	local anio "2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019"
	foreach a of local anio{
		append using "$constructeddata/IMSS`a'.dta"
		}
		
	sort nss anio
    rename anio year
*Merge with annual database	
merge 1:1 nss year using "$constructeddata/income_dynam_pan_new.dta"
drop _merge

*Age definition as in master sample
drop edad
rename anio_nacimiento yob
gen age = year-yob+1
drop if age<25 | age>55

*Obtain random sample (4 million workers)
preserve
	duplicates drop nss, force
	set seed 2038947
	generate random = runiform()
	sort random
	generate insample = _n <= 4000000
	keep if insample==1	
	keep nss
	tempfile AleatoriaID
	save 	"`AleatoriaID'", replace
restore

merge m:1 nss using "`AleatoriaID'"
keep if _merge==3
drop _merge


sort nss year
drop  wage_anual_imp 


*Real wages (monthly average to consider only months per year in which we saw 
*each worker in the database)

	*Bring CPI
	rename year anio
	merge m:1 anio using "$sourcedata/INPCanual.dta"
	keep if _merge==3
	drop _merge

	gen SBCmensual=wage_anual_obs/mesesActivo
	gen SBCmensualReal=(SBCmensual/INPCanual)*100
	gen lsbcReal=ln(SBCmensualReal)

	sort nss anio
	

*Compute spells
	egen individuo=group(nss)
	tsset individuo anio
	tsfill
	gen activo=cond(nss!=.,1,0)		
	tsspell activo 	

	*Active/inactive spells
	gen sActivo=cond(_seq==1 & activo==1,1,0)
	bysort individuo: egen spellsActivo=total(sActivo)

	gen sInactivo=cond(_seq==1 & activo==0,1,0)
	bysort individuo: egen spellsInactivo=total(sInactivo)

	*Spells duration
	gen duracion=_seq if _end==1
	gen sduracionA=duracion if activo==1
	gen sduracionI=duracion if activo==0

	bysort individuo  _spell: egen duracionSpell=mean(duracion) 

*Clean gender variable
	*Very few workers change sex throughout the years. We consider this a 
	*mistake comming from raw IMSS data.
	*To have consistent sex throughout the years, we leave the mode. When the 
	*mode doesn't exist, we leave the sex observed the first time a worker 
	*appeared in the database
rename llave_sexo sexo	
gen ssexo1=sexo if _spell==1 & _seq==1
bysort individuo: egen ssexo2=mean(ssexo1)
bysort individuo: egen ssexo3=mode(sexo)
gen sex=ssexo3
replace sex=ssexo2 if ssexo3==.
drop ssexo* sexo


*Group economic activities into 9 sectors
gen actividad2=1 if actividad>=1 & actividad<=8
replace actividad2=2 if actividad>=9 & actividad<=17
replace actividad2=3 if actividad>=18 & actividad<=146
replace actividad2=4 if actividad>=147 & actividad<=152
replace actividad2=5 if actividad>=153 & actividad<=154
replace actividad2=6 if actividad>=155 & actividad<=216
replace actividad2=7 if actividad>=217 & actividad<=229
replace actividad2=8 if actividad>=230 & actividad<=265
replace actividad2=9 if actividad>=266 & actividad<=276
replace actividad2=0 if actividad==.


*Labels
label var actividad2    `"Sector"'
label define actividad2_lbl 1 `"Agricultural"'
label define actividad2_lbl 2 `"Mining"', add
label define actividad2_lbl 3`"Manufacturing"', add
label define actividad2_lbl 4 `"Construction"', add
label define actividad2_lbl 5 `"Electricity and water supply"', add
label define actividad2_lbl 6 `"Trade"', add
label define actividad2_lbl 7 `"Transportation and Communications"', add
label define actividad2_lbl 8 `"Services for firms, households and individuals"', add
label define actividad2_lbl 9 `"Social and community services"', add
label define actividad2_lbl 0 `"Missing"', add
label values actividad2 actividad2_lbl


label var entidad    `"State"'
label define entidad_lbl 1 `"Aguascalientes"'
label define entidad_lbl 2 `"Baja California"', add
label define entidad_lbl 3 `"Baja California Sur"', add
label define entidad_lbl 4 `"Campeche"', add
label define entidad_lbl 5 `"Coahuila"', add
label define entidad_lbl 6 `"Colima"', add
label define entidad_lbl 7 `"Chiapas"', add
label define entidad_lbl 8 `"Chihuahua"', add
label define entidad_lbl 9 `"Ciudad de Mexico"', add
label define entidad_lbl 10 `"Durango"', add
label define entidad_lbl 11 `"Guanajuato"', add
label define entidad_lbl 12 `"Guerrero"', add
label define entidad_lbl 13 `"Hidalgo"', add
label define entidad_lbl 14 `"Jalisco"', add
label define entidad_lbl 15 `"Estado de Mexico"', add
label define entidad_lbl 16 `"Michoacen"', add
label define entidad_lbl 17 `"Morelos"', add
label define entidad_lbl 18 `"Nayarit"', add
label define entidad_lbl 19 `"Nuevo Leon"', add
label define entidad_lbl 20 `"Oaxaca"', add
label define entidad_lbl 21 `"Puebla"', add
label define entidad_lbl 22 `"Queretaro"', add
label define entidad_lbl 23 `"Quintana Roo"', add
label define entidad_lbl 24 `"San Luis Potosi"', add
label define entidad_lbl 25 `"Sinaloa"', add
label define entidad_lbl 26 `"Sonora"', add
label define entidad_lbl 27 `"Tabasco"', add
label define entidad_lbl 28 `"Tamaulipas"', add
label define entidad_lbl 29 `"Tlaxcala"', add
label define entidad_lbl 30 `"Veracruz"', add
label define entidad_lbl 31 `"Yucatan"', add
label define entidad_lbl 32 `"Zacatecas"', add
label values entidad entidad_lbl

label var anio   `"Year"'
label define anio_lbl 2005 `"2005"'
label define anio_lbl 2006 `"2006"', add
label define anio_lbl 2007 `"2007"', add
label define anio_lbl 2008 `"2008"', add
label define anio_lbl 2009 `"2009"', add
label define anio_lbl 2010 `"2010"', add
label define anio_lbl 2011 `"2011"', add
label define anio_lbl 2012 `"2012"', add
label define anio_lbl 2013 `"2013"', add
label define anio_lbl 2014 `"2014"', add
label define anio_lbl 2015 `"2015"', add
label define anio_lbl 2016 `"2016"', add
label define anio_lbl 2017 `"2017"', add
label define anio_lbl 2018 `"2018"', add
label define anio_lbl 2019 `"2019"', add
label values anio anio_lbl

save "$constructeddata/spells.dta", replace
	
/* End of do-file */			
	







